@@ -128,8 +128,8 @@ static TrackerDBDefinition dbs[] = {
 	  "meta.db",
 	  "meta",
 	  NULL,
-	  2000,
-	  TRACKER_DB_PAGE_SIZE_DONT_SET,
+	  TRACKER_DB_CACHE_SIZE_DEFAULT,
+	  8192,
 	  FALSE,
 	  FALSE,
 	  0 },
@@ -153,6 +153,8 @@ static gchar                *sys_tmp_dir = NULL;
 static gchar                *in_use_filename = NULL;
 static gpointer              db_type_enum_class_pointer;
 static TrackerDBManagerFlags old_flags = 0;
+static guint                 s_cache_size;
+static guint                 u_cache_size;
 
 static GStaticPrivate        interface_data_key = G_STATIC_PRIVATE_INIT;
 
@@ -191,8 +193,14 @@ db_exec_no_reply (TrackerDBInterface *iface,
 }
 
 TrackerDBManagerFlags
-tracker_db_manager_get_flags (void)
+tracker_db_manager_get_flags (guint *select_cache_size, guint *update_cache_size)
 {
+	if (select_cache_size)
+		*select_cache_size = s_cache_size;
+
+	if (update_cache_size)
+		*update_cache_size = u_cache_size;
+
 	return old_flags;
 }
 
@@ -210,7 +218,12 @@ db_set_params (TrackerDBInterface *iface,
 	tracker_db_interface_execute_query (iface, NULL, "PRAGMA auto_vacuum = 0;");
 
 	result_set = tracker_db_interface_execute_query (iface, NULL, "PRAGMA journal_mode = WAL;");
-	g_object_unref (result_set);
+	if (result_set == NULL) {
+		/* Don't just silence the problem. This pragma must return 'WAL' */
+		g_message ("Can't set journal mode to WAL");
+	} else {
+		g_object_unref (result_set);
+	}
 
 	if (page_size != TRACKER_DB_PAGE_SIZE_DONT_SET) {
 		g_message ("  Setting page size to %d", page_size);
@@ -683,7 +696,9 @@ tracker_db_manager_init_locations (void)
 gboolean
 tracker_db_manager_init (TrackerDBManagerFlags  flags,
                          gboolean              *first_time,
-                         gboolean               shared_cache)
+                         gboolean               shared_cache,
+                         guint                  select_cache_size,
+                         guint                  update_cache_size)
 {
 	GType               etype;
 	TrackerDBVersion    version;
@@ -850,7 +865,6 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 
 	} else if ((flags & TRACKER_DB_MANAGER_READONLY) == 0) {
 		/* do not do shutdown check for read-only mode (direct access) */
-
 		gboolean must_recreate;
 		gchar *journal_filename;
 
@@ -874,9 +888,9 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 			g_message ("Didn't shut down cleanly last time, doing integrity checks");
 
 			for (i = 1; i < G_N_ELEMENTS (dbs) && !must_recreate; i++) {
-				TrackerDBCursor *cursor = NULL;
-				TrackerDBStatement *stmt;
 				struct stat st;
+				GError *error = NULL;
+				TrackerDBStatement *stmt;
 
 				if (g_stat (dbs[i].abs_filename, &st) == 0) {
 					size = st.st_size;
@@ -895,27 +909,43 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 
 				loaded = TRUE;
 
-				stmt = tracker_db_interface_create_statement (dbs[i].iface, NULL,
+				stmt = tracker_db_interface_create_statement (dbs[i].iface, TRACKER_DB_STATEMENT_CACHE_TYPE_NONE, &error,
 				                                              "PRAGMA integrity_check(1)");
 
-				if (stmt) {
-					cursor = tracker_db_statement_start_cursor (stmt, NULL);
-					g_object_unref (stmt);
-				}
+				if (error != NULL) {
+					if (error->domain == TRACKER_DB_INTERFACE_ERROR &&
+					    error->code == TRACKER_DB_QUERY_ERROR) {
+						must_recreate = TRUE;
+					} else {
+						g_critical ("%s", error->message);
+					}
+					g_error_free (error);
+				} else {
+					TrackerDBCursor *cursor = NULL;
 
-				if (cursor) {
-					if (tracker_db_cursor_iter_next (cursor, NULL, NULL)) {
-						if (g_strcmp0 (tracker_db_cursor_get_string (cursor, 0, NULL), "ok") != 0) {
-							must_recreate = TRUE;
+					if (stmt) {
+						cursor = tracker_db_statement_start_cursor (stmt, NULL);
+						g_object_unref (stmt);
+					} else {
+						g_critical ("Can't create stmt for integrity_check, no error given");
+					}
+
+					if (cursor) {
+						if (tracker_db_cursor_iter_next (cursor, NULL, NULL)) {
+							if (g_strcmp0 (tracker_db_cursor_get_string (cursor, 0, NULL), "ok") != 0) {
+								must_recreate = TRUE;
+							}
 						}
+						g_object_unref (cursor);
 					}
-					g_object_unref (cursor);
 				}
 			}
 		}
 
 		if (must_recreate) {
 
+			g_message ("Database severely damaged. We will recreate it and replay the journal if available.");
+
 			if (first_time) {
 				*first_time = TRUE;
 			}
@@ -966,6 +996,17 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 		                                                        TRACKER_DB_METADATA);
 	}
 
+	tracker_db_interface_set_max_stmt_cache_size (resources_iface,
+	                                              TRACKER_DB_STATEMENT_CACHE_TYPE_SELECT,
+	                                              select_cache_size);
+
+	tracker_db_interface_set_max_stmt_cache_size (resources_iface,
+	                                              TRACKER_DB_STATEMENT_CACHE_TYPE_UPDATE,
+	                                              update_cache_size);
+
+	s_cache_size = select_cache_size;
+	u_cache_size = update_cache_size;
+
 	g_static_private_set (&interface_data_key, resources_iface, (GDestroyNotify) g_object_unref);
 
 	return TRUE;
@@ -1018,13 +1059,13 @@ tracker_db_manager_shutdown (void)
 	initialized = FALSE;
 	locations_initialized = FALSE;
 
-	if ((tracker_db_manager_get_flags () & TRACKER_DB_MANAGER_READONLY) == 0) {
+	if ((tracker_db_manager_get_flags (NULL, NULL) & TRACKER_DB_MANAGER_READONLY) == 0) {
 		/* do not delete in-use file for read-only mode (direct access) */
 		g_unlink (in_use_filename);
 	}
 
 	g_free (in_use_filename);
-        in_use_filename = NULL;
+	in_use_filename = NULL;
 }
 
 void
@@ -1385,6 +1426,15 @@ tracker_db_manager_get_db_interface (void)
 
 		tracker_db_interface_sqlite_fts_init (interface, FALSE);
 
+
+		tracker_db_interface_set_max_stmt_cache_size (interface,
+		                                              TRACKER_DB_STATEMENT_CACHE_TYPE_SELECT,
+		                                              s_cache_size);
+
+		tracker_db_interface_set_max_stmt_cache_size (interface,
+		                                              TRACKER_DB_STATEMENT_CACHE_TYPE_UPDATE,
+		                                              u_cache_size);
+
 		g_static_private_set (&interface_data_key, interface, (GDestroyNotify) g_object_unref);
 	}
 
