@@ -562,7 +562,7 @@ tracker_xmp_read (const gchar    *buffer,
  * Returns: a newly allocated #TrackerXmpData struct if XMP data was
  * found, %NULL otherwise. Free the returned struct with tracker_xmp_free().
  *
- * Since: 0.9
+ * Since: 0.10
  **/
 TrackerXmpData *
 tracker_xmp_new (const gchar *buffer,
@@ -592,7 +592,7 @@ tracker_xmp_new (const gchar *buffer,
  * Frees @data and all #TrackerXmpData members. %NULL will produce a
  * a warning.
  *
- * Since: 0.9
+ * Since: 0.10
  **/
 void
 tracker_xmp_free (TrackerXmpData *data)
@@ -655,14 +655,15 @@ tracker_xmp_free (TrackerXmpData *data)
  * Since: 0.8
  **/
 gboolean
-tracker_xmp_apply (TrackerSparqlBuilder *metadata,
+tracker_xmp_apply (TrackerSparqlBuilder *preupdate,
+                   TrackerSparqlBuilder *metadata,
                    const gchar          *uri,
                    TrackerXmpData       *data)
 {
 	GPtrArray *keywords;
 	guint i;
 
-	g_return_val_if_fail (TRACKER_IS_SPARQL_BUILDER (metadata), FALSE);
+	g_return_val_if_fail (TRACKER_SPARQL_IS_BUILDER (metadata), FALSE);
 	g_return_val_if_fail (uri != NULL, FALSE);
 	g_return_val_if_fail (data != NULL, FALSE);
 
@@ -750,11 +751,29 @@ tracker_xmp_apply (TrackerSparqlBuilder *metadata,
 	}
 
 	if (data->make || data->model) {
-		gchar *final_camera = tracker_merge_const (" ", 2, data->make, data->model);
+		gchar *equip_uri;
 
-		tracker_sparql_builder_predicate (metadata, "nfo:device");
-		tracker_sparql_builder_object_unvalidated (metadata, final_camera);
-		g_free (final_camera);
+		equip_uri = tracker_sparql_escape_uri_printf ("urn:equipment:%s:%s:",
+		                                              data->make ? data->make : "",
+		                                              data->model ? data->model : "");
+
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+		tracker_sparql_builder_subject_iri (preupdate, equip_uri);
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nfo:Equipment");
+
+		if (data->make) {
+			tracker_sparql_builder_predicate (preupdate, "nfo:manufacturer");
+			tracker_sparql_builder_object_unvalidated (preupdate, data->make);
+		}
+		if (data->model) {
+			tracker_sparql_builder_predicate (preupdate, "nfo:model");
+			tracker_sparql_builder_object_unvalidated (preupdate, data->model);
+		}
+		tracker_sparql_builder_insert_close (preupdate);
+		tracker_sparql_builder_predicate (metadata, "nfo:equipment");
+		tracker_sparql_builder_object_iri (metadata, equip_uri);
+		g_free (equip_uri);
 	}
 
 	if (data->title || data->title2 || data->pdf_title) {
